@@ -7,7 +7,7 @@ use AMF::Perl::Util::Object;
 use AMF::Perl::IO::InputStream;
 use base 'AMF::Perl::IO::Deserializer';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =for stopwords AMF Remoting
 
@@ -17,7 +17,7 @@ FLV::AMFReader - Wrapper for the AMF::Perl deserializer
 
 =head1 LICENSE
 
-Copyright 2005 Clotho Advanced Media, Inc., <cpan@clotho.com>
+Copyright 2006 Clotho Advanced Media, Inc., <cpan@clotho.com>
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -117,22 +117,7 @@ if (! __PACKAGE__->can('readMixedArray'))
       # Instead, a value with datatype == 9 is the end flag
       my $length = $self->{inputStream}->readLong();
       
-      # loop over all of the elements in the data
-      
-      my %ret;
-    KEYS:
-      while (1)
-      {
-         my $key = $self->readString();
-         # grab the type for each element
-         my $type = $self->{inputStream}->readByte();
-         # "9" is the flag for the end of the hash
-         last KEYS if $type == 9;
-         # grab each element
-         $ret{$key} = $self->readData($type);
-      }
-      
-      return \%ret;
+      return $self->readObject();
    };
 
    *readData = sub
